# Autogenerated by nbdev

d = { 'settings': { 'branch': 'master',
                'doc_baseurl': '/ohawf',
                'doc_host': 'https://miklevin.github.io',
                'git_url': 'https://github.com/miklevin/ohawf',
                'lib_path': 'ohawf'},
  'syms': { 'ohawf.core': { 'ohawf.core.Credentials': ('core.html#credentials', 'ohawf/core.py'),
                            'ohawf.core.Credentials.__init__': ('core.html#credentials.__init__', 'ohawf/core.py'),
                            'ohawf.core.Credentials.get': ('core.html#credentials.get', 'ohawf/core.py'),
                            'ohawf.core.Credentials.login': ('core.html#credentials.login', 'ohawf/core.py'),
                            'ohawf.core.Credentials.refresh_token': ('core.html#credentials.refresh_token', 'ohawf/core.py'),
                            'ohawf.core.get': ('core.html#get', 'ohawf/core.py')}}}
